@@ -4,16 +4,16 @@ use std::process::Command;
 fn main() {
     let mut version = String::from(env!("CARGO_PKG_VERSION"));
     if let Some(commit_hash) = commit_hash() {
-        version = format!("{} ({})", version, commit_hash);
+        version = format!("{version} ({commit_hash})");
     }
-    println!("cargo:rustc-env=KBS2_BUILD_VERSION={}", version);
+    println!("cargo:rustc-env=KBS2_BUILD_VERSION={version}");
 }
 
 // Cribbed from Alacritty:
 // https://github.com/alacritty/alacritty/blob/8ea6c3b/alacritty/build.rs
 fn commit_hash() -> Option<String> {
     Command::new("git")
-        .args(&["rev-parse", "--short", "HEAD"])
+        .args(["rev-parse", "--short", "HEAD"])
         .output()
         .ok()
         .filter(|output| output.status.success())
