@@ -1,16 +1,15 @@
 use std::collections::HashMap;
 use std::fs;
 use std::io::{BufRead, BufReader, BufWriter, Read, Write};
-use std::os::unix::io::AsRawFd;
 use std::os::unix::net::{UnixListener, UnixStream};
 use std::path::PathBuf;
 use std::process::{Command, Stdio};
 use std::thread;
 use std::time::Duration;
 
+use age::secrecy::{ExposeSecret as _, SecretString};
 use anyhow::{anyhow, Context, Result};
 use nix::unistd::Uid;
-use secrecy::{ExposeSecret, Secret, SecretString};
 use serde::de::DeserializeOwned;
 use serde::{Deserialize, Serialize};
 
@@ -94,7 +93,7 @@ trait Message {
         // one line before expecting a response), but it's one less thing to think about.
         // NOTE(ww): Safe unwrap: we only perform after checking `is_ok`, and we capture
         // the error by using `Result<Vec<_>, _>` with `collect`.
-        #[allow(clippy::unwrap_used)]
+        #[allow(clippy::unwrap_used, clippy::unbuffered_bytes)]
         let data: Result<Vec<_>, _> = reader
             .bytes()
             .take_while(|b| b.is_ok() && *b.as_ref().unwrap() != b'\n')
@@ -110,7 +109,7 @@ trait Message {
         Self: Serialize,
     {
         serde_json::to_writer(&mut writer, &self)?;
-        writer.write_all(&[b'\n'])?;
+        writer.write_all(b"\n")?;
         writer.flush()?;
 
         Ok(())
@@ -176,7 +175,7 @@ impl Agent {
             .spawn()?;
 
         for attempt in 0..10 {
-            log::debug!("waiting for agent, loop {}...", attempt);
+            log::debug!("waiting for agent, loop {attempt}...");
             thread::sleep(Duration::from_millis(10));
             if agent_path.exists() {
                 return Ok(());
@@ -210,7 +209,7 @@ impl Agent {
         use nix::sys::socket::getsockopt;
         use nix::sys::socket::sockopt::PeerCredentials;
 
-        if let Ok(cred) = getsockopt(stream.as_raw_fd(), PeerCredentials) {
+        if let Ok(cred) = getsockopt(stream, PeerCredentials) {
             cred.uid() == Uid::effective().as_raw()
         } else {
             log::error!("getsockopt failed; treating as auth failure");
@@ -229,7 +228,7 @@ impl Agent {
     fn auth_client(&self, stream: &UnixStream) -> bool {
         use nix::unistd;
 
-        if let Ok((peer_uid, _)) = unistd::getpeereid(stream.as_raw_fd()) {
+        if let Ok((peer_uid, _)) = unistd::getpeereid(stream) {
             peer_uid == Uid::effective()
         } else {
             log::error!("getpeereid failed; treating as auth failure");
@@ -237,6 +236,60 @@ impl Agent {
         }
     }
 
+    /// Handles an inner request payload, i.e. one of potentially several
+    /// requests made during a client's connection.
+    fn handle_request_body(&mut self, body: RequestBody) -> Response {
+        match body {
+            RequestBody::UnwrapKey(pubkey, keyfile, password) => {
+                let password = SecretString::from(password);
+                // If the running agent is already tracking an unwrapped key for this
+                // pubkey, return early with a success.
+                #[allow(clippy::map_entry)]
+                if self.unwrapped_keys.contains_key(&pubkey) {
+                    log::debug!("client requested unwrap for already unwrapped keyfile: {keyfile}");
+                    Response::Success("OK; agent already has unwrapped key".into())
+                } else {
+                    match RageLib::unwrap_keyfile(&keyfile, password) {
+                        Ok(unwrapped_key) => {
+                            self.unwrapped_keys.insert(pubkey, (keyfile, unwrapped_key));
+                            Response::Success("OK; unwrapped key ready".into())
+                        }
+                        Err(e) => {
+                            log::error!("keyfile unwrap failed: {e:?}");
+                            Response::Failure(FailureKind::Unwrap(e.to_string()))
+                        }
+                    }
+                }
+            }
+            RequestBody::QueryUnwrappedKey(pubkey) => {
+                if self.unwrapped_keys.contains_key(&pubkey) {
+                    Response::Success("OK".into())
+                } else {
+                    Response::Failure(FailureKind::Query)
+                }
+            }
+            RequestBody::GetUnwrappedKey(pubkey) => {
+                if let Some((_, unwrapped_key)) = self.unwrapped_keys.get(&pubkey) {
+                    log::debug!("successful key request for pubkey: {pubkey}");
+                    Response::Success(unwrapped_key.expose_secret().into())
+                } else {
+                    log::error!("unknown pubkey requested: {}", &pubkey);
+                    Response::Failure(FailureKind::Query)
+                }
+            }
+            RequestBody::FlushKeys => {
+                self.unwrapped_keys.clear();
+                log::debug!("successfully flushed all unwrapped keys");
+                Response::Success("OK".into())
+            }
+            RequestBody::Quit => {
+                self.quitting = true;
+                log::debug!("agent exit requested");
+                Response::Success("OK".into())
+            }
+        }
+    }
+
     /// Handles a single client connection.
     /// Individual clients may issue multiple requests in a single session.
     fn handle_client(&mut self, stream: UnixStream) {
@@ -254,7 +307,7 @@ impl Agent {
             let line = match line {
                 Ok(line) => line,
                 Err(e) => {
-                    log::error!("i/o error: {:?}", e);
+                    log::error!("i/o error: {e:?}");
                     // This can fail, but we don't care.
                     let _ = Response::Failure(FailureKind::Io(e.to_string())).write(&mut writer);
                     return;
@@ -264,7 +317,7 @@ impl Agent {
             let req: Request = match serde_json::from_str(&line) {
                 Ok(req) => req,
                 Err(e) => {
-                    log::error!("malformed req: {:?}", e);
+                    log::error!("malformed req: {e:?}");
                     // This can fail, but we don't care.
                     let _ =
                         Response::Failure(FailureKind::Malformed(e.to_string())).write(&mut writer);
@@ -278,58 +331,7 @@ impl Agent {
                 return;
             }
 
-            let resp = match req.body {
-                RequestBody::UnwrapKey(pubkey, keyfile, password) => {
-                    let password = Secret::new(password);
-                    // If the running agent is already tracking an unwrapped key for this
-                    // pubkey, return early with a success.
-                    #[allow(clippy::map_entry)]
-                    if self.unwrapped_keys.contains_key(&pubkey) {
-                        log::debug!(
-                            "client requested unwrap for already unwrapped keyfile: {}",
-                            keyfile
-                        );
-                        Response::Success("OK; agent already has unwrapped key".into())
-                    } else {
-                        match RageLib::unwrap_keyfile(&keyfile, password) {
-                            Ok(unwrapped_key) => {
-                                self.unwrapped_keys.insert(pubkey, (keyfile, unwrapped_key));
-                                Response::Success("OK; unwrapped key ready".into())
-                            }
-                            Err(e) => {
-                                log::error!("keyfile unwrap failed: {:?}", e);
-                                Response::Failure(FailureKind::Unwrap(e.to_string()))
-                            }
-                        }
-                    }
-                }
-                RequestBody::QueryUnwrappedKey(pubkey) => {
-                    if self.unwrapped_keys.contains_key(&pubkey) {
-                        Response::Success("OK".into())
-                    } else {
-                        Response::Failure(FailureKind::Query)
-                    }
-                }
-                RequestBody::GetUnwrappedKey(pubkey) => {
-                    if let Some((_, unwrapped_key)) = self.unwrapped_keys.get(&pubkey) {
-                        log::debug!("successful key request for pubkey: {}", pubkey);
-                        Response::Success(unwrapped_key.expose_secret().into())
-                    } else {
-                        log::error!("unknown pubkey requested: {}", &pubkey);
-                        Response::Failure(FailureKind::Query)
-                    }
-                }
-                RequestBody::FlushKeys => {
-                    self.unwrapped_keys.clear();
-                    log::debug!("successfully flushed all unwrapped keys");
-                    Response::Success("OK".into())
-                }
-                RequestBody::Quit => {
-                    self.quitting = true;
-                    log::debug!("agent exit requested");
-                    Response::Success("OK".into())
-                }
-            };
+            let resp = self.handle_request_body(req.body);
 
             // This can fail, but we don't care.
             let _ = resp.write(&mut writer);
@@ -365,7 +367,7 @@ impl Agent {
                     }
                 }
                 Err(e) => {
-                    log::error!("connect error: {:?}", e);
+                    log::error!("connect error: {e:?}");
                     continue;
                 }
             }
@@ -418,7 +420,7 @@ impl Client {
     /// Instruct the agent to unwrap the given keyfile, using the given password.
     /// The keyfile path and its unwrapped contents are associated with the given pubkey.
     pub fn add_key(&self, pubkey: &str, keyfile: &str, password: SecretString) -> Result<()> {
-        log::debug!("add_key: requesting that agent unwrap {}", keyfile);
+        log::debug!("add_key: requesting that agent unwrap {keyfile}");
 
         let body = RequestBody::UnwrapKey(
             pubkey.into(),
@@ -429,7 +431,7 @@ impl Client {
 
         match resp {
             Response::Success(msg) => {
-                log::debug!("agent reports success: {}", msg);
+                log::debug!("agent reports success: {msg}");
                 Ok(())
             }
             Response::Failure(kind) => Err(anyhow!("adding key to agent failed: {:?}", kind)),
@@ -438,7 +440,7 @@ impl Client {
 
     /// Ask the agent whether it has an unwrapped key for the given pubkey.
     pub fn query_key(&self, pubkey: &str) -> Result<bool> {
-        log::debug!("query_key: asking whether agent has key for {}", pubkey);
+        log::debug!("query_key: asking whether agent has key for {pubkey}");
 
         let body = RequestBody::QueryUnwrappedKey(pubkey.into());
         let resp = self.request(body)?;
@@ -452,7 +454,7 @@ impl Client {
 
     /// Ask the agent for the unwrapped key material for the given pubkey.
     pub fn get_key(&self, pubkey: &str) -> Result<String> {
-        log::debug!("get_key: requesting unwrapped key for {}", pubkey);
+        log::debug!("get_key: requesting unwrapped key for {pubkey}");
 
         let body = RequestBody::GetUnwrappedKey(pubkey.into());
         let resp = self.request(body)?;
