@@ -1,18 +1,17 @@
 use std::convert::TryInto;
 use std::env;
 use std::fmt::Write as _;
-use std::io::{self, Read, Seek, Write};
+use std::io::{self, stdin, IsTerminal, Read, Seek, Write};
 use std::path::{Path, PathBuf};
 use std::process;
 
+use age::secrecy::{ExposeSecret as _, SecretBox};
 use anyhow::{anyhow, Result};
 use arboard::Clipboard;
-use atty::Stream;
 use clap::ArgMatches;
 use daemonize::Daemonize;
 use inquire::Confirm;
 use nix::unistd::{fork, ForkResult};
-use secrecy::{ExposeSecret, Secret};
 
 use crate::kbs2::agent;
 use crate::kbs2::backend::{self, Backend};
@@ -143,7 +142,7 @@ pub fn new(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     let session: Session = config.try_into()?;
 
     if let Some(pre_hook) = &session.config.commands.new.pre_hook {
-        log::debug!("pre-hook: {}", pre_hook);
+        log::debug!("pre-hook: {pre_hook}");
         session.config.call_hook(pre_hook, &[])?;
     }
 
@@ -172,7 +171,7 @@ pub fn new(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     session.add_record(&record)?;
 
     if let Some(post_hook) = &session.config.commands.new.post_hook {
-        log::debug!("post-hook: {}", post_hook);
+        log::debug!("post-hook: {post_hook}");
         session.config.call_hook(post_hook, &[label])?;
     }
 
@@ -238,7 +237,7 @@ pub fn rm(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     }
 
     if let Some(post_hook) = &session.config.commands.rm.post_hook {
-        log::debug!("post-hook: {}", post_hook);
+        log::debug!("post-hook: {post_hook}");
         session.config.call_hook(post_hook, &labels)?;
     }
 
@@ -265,7 +264,7 @@ pub fn rename(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     session.rename_record(old_label, new_label)?;
 
     if let Some(post_hook) = &session.config.commands.rename.post_hook {
-        log::debug!("post-hook: {}", post_hook);
+        log::debug!("post-hook: {post_hook}");
         session
             .config
             .call_hook(post_hook, &[old_label, new_label])?;
@@ -314,7 +313,7 @@ pub fn pass(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     let session: Session = config.try_into()?;
 
     if let Some(pre_hook) = &session.config.commands.pass.pre_hook {
-        log::debug!("pre-hook: {}", pre_hook);
+        log::debug!("pre-hook: {pre_hook}");
         session.config.call_hook(pre_hook, &[])?;
     }
 
@@ -342,14 +341,14 @@ pub fn pass(matches: &ArgMatches, config: &config::Config) -> Result<()> {
                 _ => {}
             }
         }
-    } else if atty::isnt(Stream::Stdout) {
+    } else if !stdin().is_terminal() {
         print!("{password}");
     } else {
         println!("{password}");
     }
 
     if let Some(post_hook) = &session.config.commands.pass.post_hook {
-        log::debug!("post-hook: {}", post_hook);
+        log::debug!("post-hook: {post_hook}");
         session.config.call_hook(post_hook, &[])?;
     }
 
@@ -370,7 +369,7 @@ fn clip(password: String, session: &Session) -> Result<()> {
         clipboard.clear()?;
 
         if let Some(clear_hook) = &session.config.commands.pass.clear_hook {
-            log::debug!("clear-hook: {}", clear_hook);
+            log::debug!("clear-hook: {clear_hook}");
             session.config.call_hook(clear_hook, &[])?;
         }
     }
@@ -426,7 +425,7 @@ pub fn edit(matches: &ArgMatches, config: &config::Config) -> Result<()> {
 
     let (editor, editor_args) = util::parse_and_split_args(&editor)?;
 
-    log::debug!("editor: {}, args: {:?}", editor, editor_args);
+    log::debug!("editor: {editor}, args: {editor_args:?}");
 
     #[allow(clippy::unwrap_used)]
     let label = matches.get_one::<String>("label").unwrap();
@@ -439,7 +438,7 @@ pub fn edit(matches: &ArgMatches, config: &config::Config) -> Result<()> {
         .args(&editor_args)
         .arg(file.path())
         .status()
-        .map_or(false, |o| o.success())
+        .is_ok_and(|o| o.success())
     {
         return Err(anyhow!("failed to run the editor"));
     }
@@ -458,7 +457,7 @@ pub fn edit(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     session.add_record(&record)?;
 
     if let Some(post_hook) = &session.config.commands.edit.post_hook {
-        log::debug!("post-hook: {}", post_hook);
+        log::debug!("post-hook: {post_hook}");
         session.config.call_hook(post_hook, &[])?;
     }
 
@@ -587,14 +586,17 @@ pub fn rekey(matches: &ArgMatches, config: &config::Config) -> Result<()> {
     }
 
     // Decrypt and collect all records.
-    let records: Vec<Secret<record::Record>> = {
+    let records: Vec<SecretBox<record::Record>> = {
         let records: Result<Vec<record::Record>> = session
             .record_labels()?
             .iter()
             .map(|l| session.get_record(l))
             .collect();
 
-        records?.into_iter().map(Secret::new).collect()
+        records?
+            .into_iter()
+            .map(|r| SecretBox::new(Box::new(r)))
+            .collect()
     };
 
     // Get a new master password.
