@@ -2,13 +2,14 @@ use std::collections::HashMap;
 use std::env;
 use std::ffi::OsStr;
 use std::fs;
+use std::io::{stdin, IsTerminal};
 use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 
+use age::secrecy::SecretString;
 use anyhow::{anyhow, Result};
 use clap::ArgMatches;
 use lazy_static::lazy_static;
-use secrecy::SecretString;
 use serde::{de, Deserialize, Serialize};
 use xdg::BaseDirectories;
 
@@ -312,7 +313,7 @@ pub struct RuntimeConfig<'a> {
     pub matches: &'a ArgMatches,
 }
 
-impl<'a> RuntimeConfig<'a> {
+impl RuntimeConfig<'_> {
     pub fn generator(&self) -> Result<&GeneratorConfig> {
         // If the user explicitly requests a specific generator, use it.
         // Otherwise, use the default generator, which is always present.
@@ -329,7 +330,7 @@ impl<'a> RuntimeConfig<'a> {
     }
 
     pub fn terse(&self) -> bool {
-        atty::isnt(atty::Stream::Stdin) || *self.matches.get_one::<bool>("terse").unwrap_or(&false)
+        !stdin().is_terminal() || *self.matches.get_one::<bool>("terse").unwrap_or(&false)
     }
 }
 
@@ -391,7 +392,7 @@ pub fn initialize<P: AsRef<Path>>(
         RageLib::create_keypair(&keyfile)?
     };
 
-    log::debug!("public key: {}", public_key);
+    log::debug!("public key: {public_key}");
 
     let serialized = {
         let config_dir = config_dir
